<!-- public_access_block_configuration partial -->
<script id="services.s3.public_access_block_configuration.partial" type="text/x-handlebars-template">
    <div class="list-group-item">
        <h4 class="list-group-item-heading"><span id="s3.buckets.{{@key}}.public_access_block_configuration.public_access_block">Public Access Block Configuration</span></h4>
        <div class="list-group-item-text item-margin">Ignore Public ACLs:
            {{convert_bool_to_enabled public_access_block_configuration.IgnorePublicAcls}}
        </div>
        <div class="list-group-item-text item-margin">Block Public Policies:
            {{convert_bool_to_enabled public_access_block_configuration.BlockPublicPolicy}}
        </div>
        <div class="list-group-item-text item-margin">Block Public ACLs:
            {{convert_bool_to_enabled public_access_block_configuration.BlockPublicAcls}}
        </div>
        <div class="list-group-item-text item-margin">Restrict Public Buckets:
            {{convert_bool_to_enabled public_access_block_configuration.RestrictPublicBuckets}}
        </div>
    </div>
</script>
<script>
      Handlebars.registerPartial("services.s3.public_access_block_configuration", $("#services\\.s3\\.public_access_block_configuration\\.partial").html());
</script>

