<footer id="report-footer">
    <div>
        <p>Scout Suite is an open-source tool released by <a href="https://www.nccgroup.trust" rel="author" target="_blank">NCC Group</a>
            <img src="inc-scoutsuite/favicon.ico" rel="icon" type="image/x-icon" alt="Red dot" />
        </p>
    </div>
</footer>
