
    <!-- RDS instance partial -->
    <script id="services.rds.regions.id.vpcs.id.instances.partial" type="text/x-handlebars-template">
        <div id="resource-name" class="list-group-item active">
            <h4 class="list-group-item-heading">{{name}}</h4>
        </div>
        <div class="list-group-item">
          <h4>Information</h4>
            <ul>
                <li class="list-group-item-text">ARN: <samp>{{arn}}</samp></li>
                <li class="list-group-item-text">Region: <samp>{{region}}</samp></li>
                <li class="list-group-item-text">Engine: <samp>{{Engine}}</samp></li>
                <li class="list-group-item-text">Created: {{format_date InstanceCreateTime}}</li>
                <li class="list-group-item-text">Status: <samp>{{makeTitle DBInstanceStatus}}</samp></li>
                <li class="list-group-item-text">Is Read Replica: <samp>{{is_read_replica}}</samp></li>
                <li class="list-group-item-text">Auto Minor Version Upgrade: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.AutoMinorVersionUpgrade">{{convert_bool_to_enabled AutoMinorVersionUpgrade}}</span></li>
                <li class="list-group-item-text">Multi Availability Zones: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.MultiAZ">{{convert_bool_to_enabled MultiAZ}}</span></li>
                <li class="list-group-item-text">Instance Class: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.DBInstanceClass"><samp>{{DBInstanceClass}}</samp></span></li>
                <li class="list-group-item-text">Backup Retention Period: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.BackupRetentionPeriod">{{BackupRetentionPeriod}} days</span>
                <li class="list-group-item-text">Enhanced Monitoring:
                    <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.EnhancedMonitoringResourceArn">{{convert_bool_to_enabled EnhancedMonitoringResourceArn}}</span>
                </li>
                <li class="list-group-item-text">Encrypted Storage: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.StorageEncrypted">{{convert_bool_to_enabled StorageEncrypted}}</span></li>
                <li class="list-group-item-text">CA Certificate: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.CACertificateIdentifier"><samp>{{CACertificateIdentifier}}</samp></span></li>
            </ul>
        </div>
        <div class="list-group-item">
            <h4>Network</h4>
            <ul>
                <li class="list-group-item-text">Endpoint: <samp>{{Endpoint.Address}}:{{Endpoint.Port}}</samp></li>
                <li class="list-group-item-text">Publicly Accessible: <span id="rds.regions.{{region}}.vpcs.{{vpc}}.instances.{{@key}}.instance_publicly_accessible">{{convert_bool_to_enabled PubliclyAccessible}}</span>
            </ul>
        </div>
    </script>
    <script>
      Handlebars.registerPartial("services.rds.regions.id.vpcs.id.instances", $("#services\\.rds\\.regions\\.id\\.vpcs\\.id\\.instances\\.partial").html());
    </script>

    <!-- Single RDS instance template -->
    <script id="single_rds_instance-template" type="text/x-handlebars-template">
        {{> modal-template template='services.rds.regions.id.vpcs.id.instances'}}
    </script>
    <script>
        var single_rds_instance_template = Handlebars.compile($("#single_rds_instance-template").html());
    </script>
