
<!-- Stackdriver All Logging metrics partial -->
<script id="services.stackdriverlogging.projects.id.logging_metrics.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Project Ownership Assignment/Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.project_ownership_assignments">{{project_ownership_assignments}}</span></div>
        <div class="list-group-item-text item-margin">Audit Configuration Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.audit_config_change">{{audit_config_change}}</span></div>
        <div class="list-group-item-text item-margin">Custom Role Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.custom_role_change">{{custom_role_change}}</span></div>
        <div class="list-group-item-text item-margin">VPC Network Firewall Rule Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.vpc_network_firewall_rule_change">{{vpc_network_firewall_rule_change}}</span></div>
        <div class="list-group-item-text item-margin">VPC Network Route Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.vpc_network_route_change">{{vpc_network_route_change}}</span></div>
        <div class="list-group-item-text item-margin">VPC Network Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.vpc_network_change">{{vpc_network_change}}</span></div>
        <div class="list-group-item-text item-margin">Cloud Storage IAM Permission Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.cloud_storage_iam_permission_change">{{cloud_storage_iam_permission_change}}</span></div>
        <div class="list-group-item-text item-margin">SQL Instance Configuration Changes Log Metric Filter Exist: <span id="stackdriverlogging.projects.{{@../key}}.logging_metrics.{{@key}}.sql_instance_conf_change">{{sql_instance_conf_change}}</span></div>

    </div>
</script>

<script>
    Handlebars.registerPartial("services.stackdriverlogging.projects.id.logging_metrics", $("#services\\.stackdriverlogging\\.projects\\.id\\.logging_metrics\\.partial").html());
</script>

<!-- Single stackdriverlogging metric template -->
<script id="single_stackdriverlogging_logging_metrics-template" type="text/x-handlebars-template">
    {{> modal-template template='services.stackdriverlogging.projects.id.logging_metrics'}}
</script>
<script>
    var single_stackdriverlogging_logging_metrics_template = Handlebars.compile($("#single_stackdriverlogging_logging_metrics-template").html());
</script>
