<!-- Redshift parameter group partial -->

<script id="services.redshift.regions.id.parameter_groups.partial" type="text/x-handlebars-template">
    <div class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">ARN: <samp>{{arn}}</samp></div>
        <div class="list-group-item-text item-margin">Description: <samp>{{description}}</samp></div>
        <div class="list-group-item-text item-margin">Group Family: <samp>{{family}}</samp></div>
        <div class="list-group-item-text item-margin">Default Parameter Group: <samp>{{is_default}}</samp></div>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Parameters</h4>
        <ul>
            {{#each parameters}}
            <div class="list-group-item-text item-margin">ARN: <samp>{{arn}}</samp></div>
            <li class="list-group-item-text"><samp>{{@key}}</samp>:
                <span id="redshift.regions.{{../region}}.parameter_groups.{{@../key}}.{{@key}}"><samp>{{value}}</samp></span>
            </li>
            {{/each}}
        </ul>
    </div>
</script>
<script>
    Handlebars.registerPartial("services.redshift.regions.id.parameter_groups", $("#services\\.redshift\\.regions\\.id\\.parameter_groups\\.partial").html());
</script>

